---
meta:
    title: Z-Index Tokens
    description: Z-indexes are used to stack components in a logical manner.
---

# Z-Index Tokens

Z-indexes are used to stack components in a logical manner.

| Token                         | Value |
| ----------------------------- | ----- |
| `--terra-z-index-drawer`      | 700   |
| `--terra-z-index-dialog`      | 800   |
| `--terra-z-index-dropdown`    | 900   |
| `--terra-z-index-alert-group` | 950   |
| `--terra-z-index-tooltip`     | 1000  |
